==> owncloud-news_5.3.8%2Bdfsg.orig.tar.gz: news-5.3.8/l10n/tr.js <==
OC.L10N.register(
    "news",
    {
    "Feed contains invalid XML" : "Besleme, geçersiz XML içeriyor",
    "Could not find a feed" : "Bir besleme bulunamadı",
    "Detected feed format is not supported" : "Tespit edilen biçim desteklenmiyor",
    "SSL Certificate is invalid" : "SSL Sertifikası geçersiz",
    "Website not found" : "Web sitesi bulunamadı",
    "More redirects than allowed, aborting" : "İzin verilenden daha fazla yeniden yönlendirme. İptal ediliyor",
    "Bigger than maximum allowed size" : "İzin verilen boyuttan daha büyük",
    "Request timed out" : "İstek zaman aşımına uğradı",
    "Request failed, network connection unavailable!" : "İstek başarısız, ağ bağlantısı kullanılamıyor!",
    "Request unauthorized. Are you logged in?" : "İstek yetkisiz. Oturumunuz açık mı?",
    "Request forbidden. Are you an admin?" : "İsteğe izin verilmedi. Bir yönetici misiniz?",
    "Token expired or app not enabled! Reload the page!" : "Belirteç süresi doldu ya da uygulama etkin değil! Sayfayı yenileyin!",
    "Internal server error! Please check your " : "Dahili sunucu hatası! Lütfen denetleyin:",
    "Request failed, ownCloud is in currently " : "İstek başarısız, ownCloud şu anda",
    "Can not add feed: Exists already" : "Besleme eklenemiyor: Zaten mevcut",
    "Articles without feed" : "Beslemesiz makaleler",
    "Can not add folder: Exists already" : "Klasör eklenemiyor: Zaten mevcut",
    "Use ownCloud cron for updates" : "Güncellemeler için ownCloud cron'u kullan",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Uygulamaya dahil edilmiş Python güncelleyicisi gibi bir özel güncelleştirici çalıştırıyorsanız bunu devre dışı bırakın",
    "Purge interval" : "Temizleme aralığı",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Silinen besleme ve klasörlerin, veritabanından kaldırılacağı asgari süre; 60 altındaki saniyeler yoksayılır",
    "Maximum read count per feed" : "Besleme başına azami okuma sayısı",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" : "Temizleme görevinde silinmeyecek, besleme başına okunabilecek azami makale sayısını tanımlar. Eski makaleler okunduktan sonra yeniden görülüyorsa, bu değeri arttırın. -1 gibi negatif değerler bu özelliği tamamen kapatacaktır.",
    "Maximum redirects" : "En fazla yeniden yönlendirme",
    "How many redirects the feed fetcher should follow" : "Besleme getirici kaç yönlendirmeyi takip etmeli",
    "Maximum feed page size" : "Azami besleme sayfa boyutu",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Bayt cinsinden azami besleme boyutu. RSS/Atom sayfası bu değerden daha büyükse, güncelleme iptal edilecek",
    "Feed fetcher timeout" : "Besleme getirici zaman aşımı",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Bir RSS veya Atom beslemesinin yüklenmesi için beklenilecek azami süre. Uzun sürüyorsa iptal edilecek",
    "Explore Service URL" : "Keşfetme Hizmet URL'si",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Belirtilmişse, hizmetin URL'si beslemeyi keşfetme bölümünde beslemelerin görüntülenebilmesi için sorgulanacak. Dahili keşfetme hizmeti için bu alanı boş bırakın",
    "Saved" : "Kaydedildi",
    "Download" : "İndir",
    "Close" : "Kapat",
    "Ajax cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." : "Ajax cron kipi tespit edildi! Beslemeleriniz düzgün şekilde güncellenmeyecek. Bir işletim sistemi cron görevi veya özel bir güncelleyici kullanmanız önerilir.",
    "How to set up the operating system cron" : "İşletim sistemi cron görevi nasıl ayarlanır",
    "How to set up a custom updater (faster and no possible deadlock) " : "Özel bir güncelleyici nasıl ayarlanır (daha hızlı ve kördüğüm ihtimali yok)",
    "Subscribe" : "Abone ol",
    "Refresh" : "Yenile",
    "No articles available" : "Hiç makale yok",
    "No unread articles available" : "Okunmamış makale yok",
    "Open website" : "Web sitesini aç",
    "Star article" : "Makaleyi yıldızla",
    "Unstar article" : "Makale yıldızını kaldır",
    "Keep article unread" : "Makaleyi okunmadı olarak bırak",
    "Remove keep article unread" : "Makaleyi okunmadı olarak bırak",
    "by" : "yazar",
    "from" : "kaynak",
    "Play audio" : "Ses oynat",
    "Download video" : "Video indir",
    "Download audio" : "Ses indir",
    "Keyboard shortcut" : "Klavye kısayolu",
    "Description" : "Açıklama",
    "right" : "sağ",
    "Jump to next article" : "Sonraki makaleye atla",
    "left" : "sol",
    "Jump to previous article" : "Önceki makaleye atla",
    "Toggle star article" : "Makale yıldızını aç/kapat",
    "Star article and jump to next one" : "Makaleyi yıldızla ve sonrakine atla",
    "Toggle keep current article unread" : "Geçerli makaleyi okunmamış tut özelliğini aç/kapat",
    "Open article in new tab" : "Makaleyi yeni sekmede aç",
    "Toggle expand article in compact view" : "Sıkışık görünümde makaleyi genişlet/daralt",
    "Load next feed" : "Sonraki beslemeyi yükle",
    "Load previous feed" : "Önceki beslemeyi yükle",
    "Load next folder" : "Sonraki klasörü yükle",
    "Load previous folder" : "Önceki klasörü yükle",
    "Scroll to active navigation entry" : "Gezinti girdisini etkinleştirmek için kaydır",
    "Focus search field" : "Arama alanına odaklan",
    "Mark current article's feed/folder read" : "Geçerli makalenin beslemesini/klasörünü okundu işaretle",
    "Web address" : "Web adresi",
    "Feed exists already!" : "Besleme zaten mevcut!",
    "Folder" : "Klasör",
    "No folder" : "Klasör yok",
    "New folder" : "Yeni klasör",
    "Folder name" : "Klasör adı",
    "Go back" : "Geri dön",
    "Folder exists already!" : "Klasör zaten mevcut!",
    "New Folder" : "Yeni Klasör",
    "Create" : "Oluştur",
    "Explore" : "Keşfet",
    "Deleted feed" : "Beslemeyi sil",
    "Undo delete feed" : "Beslemeyi geri al",
    "Rename" : "Yeniden adlandır",
    "Menu" : "Menü",
    "No feed ordering" : "Besleme sıralaması yok",
    "Reversed feed ordering" : "Ters besleme sıralaması",
    "Normal feed ordering" : "Normal besleme sıralaması",
    "Rename feed" : "Beslemeyi yeniden adlandır",
    "Delete feed" : "Beslemeyi sil",
    "Mark all articles read" : "Tüm makaleleri okundu işaretle",
    "Dismiss" : "İptal et",
    "Collapse" : "Daralt",
    "Deleted folder" : "Klasör silindi",
    "Undo delete folder" : "Klasör silmeyi geri al",
    "Rename folder" : "Klasörü yeniden adlandır",
    "Delete folder" : "Klasörü sil",
    "Starred" : "Yıldızlı",
    "Unread articles" : "Okunmamış makaleler",
    "All articles" : "Tüm makaleler",
    "Settings" : "Ayarlar",
    "Keyboard shortcuts" : "Klavye kısayolları",
    "Disable mark read through scrolling" : "Kaydırma sırasında okundu olarak işaretlemeyi kapat",
    "Compact view" : "Sıkışık görünüm",
    "Expand articles on key navigation" : "Tuşla gezinme sırasında makaleleri genişlet",
    "Show all articles" : "Tüm makaleleri göster",
    "Reverse ordering (oldest on top)" : "Sıralamayı tersine çevir (en eski üstte)",
    "Subscriptions (OPML)" : "Abonelikler (OPML)",
    "Import" : "İçe aktar",
    "Export" : "Dışa aktar",
    "Error when importing: file does not contain valid OPML" : "Dosya alımında hata: dosya geçerli OPML içermiyor",
    "Unread/Starred Articles" : "Okunmamış/Yıldızlı Makaleler",
    "Error when importing: file does not contain valid JSON" : "İçe alınırken hata: dosya geçerli JSON içermiyor"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-news_6.0.4%2Bdfsg.orig.tar.gz: news-6.0.4/l10n/tr.js <==
OC.L10N.register(
    "news",
    {
    "Feed contains invalid XML" : "Besleme, geçersiz XML içeriyor",
    "Feed not found: either the website does not provide a feed or blocks access. To rule out blocking, try to download the feed on your server's command line using curl: curl http://the-feed.tld" : "Besleme bulunamadı: ya web sitesi besleme sağlamıyor ya da erişimi engelliyor. Engellemeyi aşmak için beslemeyi sunucunuzdan şu curl komutunu kullanarak indirmeyi deneyin: curl http://the-feed.tld",
    "Detected feed format is not supported" : "Tespit edilen biçim desteklenmiyor",
    "SSL Certificate is invalid" : "SSL Sertifikası geçersiz",
    "Website not found" : "Web sitesi bulunamadı",
    "More redirects than allowed, aborting" : "İzin verilenden daha fazla yeniden yönlendirme. İptal ediliyor",
    "Bigger than maximum allowed size" : "İzin verilen boyuttan daha büyük",
    "Request timed out" : "İstek zaman aşımına uğradı",
    "Request failed, network connection unavailable!" : "İstek başarısız, ağ bağlantısı kullanılamıyor!",
    "Request unauthorized. Are you logged in?" : "İstek yetkisiz. Oturumunuz açık mı?",
    "Request forbidden. Are you an admin?" : "İsteğe izin verilmedi. Bir yönetici misiniz?",
    "Token expired or app not enabled! Reload the page!" : "Belirteç süresi doldu ya da uygulama etkin değil! Sayfayı yenileyin!",
    "Internal server error! Please check your " : "Dahili sunucu hatası! Lütfen denetleyin:",
    "Request failed, ownCloud is in currently " : "İstek başarısız, ownCloud şu anda",
    "Can not add feed: Exists already" : "Besleme eklenemiyor: Zaten mevcut",
    "Articles without feed" : "Beslemesiz makaleler",
    "Can not add folder: Exists already" : "Klasör eklenemiyor: Zaten mevcut",
    "Use ownCloud cron for updates" : "Güncellemeler için ownCloud cron'u kullan",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Uygulamaya dahil edilmiş Python güncelleyicisi gibi bir özel güncelleştirici çalıştırıyorsanız bunu devre dışı bırakın",
    "Purge interval" : "Temizleme aralığı",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Silinen besleme ve klasörlerin, veritabanından kaldırılacağı asgari süre; 60 altındaki saniyeler yoksayılır",
    "Maximum read count per feed" : "Besleme başına azami okuma sayısı",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" : "Temizleme görevinde silinmeyecek, besleme başına okunabilecek azami makale sayısını tanımlar. Eski makaleler okunduktan sonra yeniden görülüyorsa, bu değeri arttırın. -1 gibi negatif değerler bu özelliği tamamen kapatacaktır.",
    "Maximum redirects" : "En fazla yeniden yönlendirme",
    "How many redirects the feed fetcher should follow" : "Besleme getirici kaç yönlendirmeyi takip etmeli",
    "Maximum feed page size" : "Azami besleme sayfa boyutu",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Bayt cinsinden azami besleme boyutu. RSS/Atom sayfası bu değerden daha büyükse, güncelleme iptal edilecek",
    "Feed fetcher timeout" : "Besleme getirici zaman aşımı",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Bir RSS veya Atom beslemesinin yüklenmesi için beklenilecek azami süre. Uzun sürüyorsa iptal edilecek",
    "Explore Service URL" : "Keşfetme Hizmet URL'si",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Belirtilmişse, hizmetin URL'si beslemeyi keşfetme bölümünde beslemelerin görüntülenebilmesi için sorgulanacak. Dahili keşfetme hizmeti için bu alanı boş bırakın",
    "Saved" : "Kaydedildi",
    "Download" : "İndir",
    "Close" : "Kapat",
    "Ajax or webcron cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." : "Ajax veya webcron modu tespit edildi. Beslemeleriniz düzgün olarak güncellenemeyecektir. Özel bir güncelleyeci yada işletim sistemi cron kullanmanız önerilir.",
    "How to set up the operating system cron" : "İşletim sistemi cron görevi nasıl ayarlanır",
    "How to set up a custom updater (faster and no possible deadlock) " : "Özel bir güncelleyici nasıl ayarlanır (daha hızlı ve kördüğüm ihtimali yok)",
    "Subscribe" : "Abone ol",
    "Refresh" : "Yenile",
    "No articles available" : "Hiç makale yok",
    "No unread articles available" : "Okunmamış makale yok",
    "Open website" : "Web sitesini aç",
    "Star article" : "Makaleyi yıldızla",
    "Unstar article" : "Makale yıldızını kaldır",
    "Keep article unread" : "Makaleyi okunmadı olarak bırak",
    "Remove keep article unread" : "Makaleyi okunmadı olarak bırak",
    "by" : "yazar",
    "from" : "kaynak",
    "Play audio" : "Ses oynat",
    "Download video" : "Video indir",
    "Download audio" : "Ses indir",
    "Keyboard shortcut" : "Klavye kısayolu",
    "Description" : "Açıklama",
    "right" : "sağ",
    "Jump to next article" : "Sonraki makaleye atla",
    "left" : "sol",
    "Jump to previous article" : "Önceki makaleye atla",
    "Toggle star article" : "Makale yıldızını aç/kapat",
    "Star article and jump to next one" : "Makaleyi yıldızla ve sonrakine atla",
    "Toggle keep current article unread" : "Geçerli makaleyi okunmamış tut özelliğini aç/kapat",
    "Open article in new tab" : "Makaleyi yeni sekmede aç",
    "Toggle expand article in compact view" : "Sıkışık görünümde makaleyi genişlet/daralt",
    "Load next feed" : "Sonraki beslemeyi yükle",
    "Load previous feed" : "Önceki beslemeyi yükle",
    "Load next folder" : "Sonraki klasörü yükle",
    "Load previous folder" : "Önceki klasörü yükle",
    "Scroll to active navigation entry" : "Gezinti girdisini etkinleştirmek için kaydır",
    "Focus search field" : "Arama alanına odaklan",
    "Mark current article's feed/folder read" : "Geçerli makalenin beslemesini/klasörünü okundu işaretle",
    "Web address" : "Web adresi",
    "Feed exists already!" : "Besleme zaten mevcut!",
    "Folder" : "Klasör",
    "No folder" : "Klasör yok",
    "New folder" : "Yeni klasör",
    "Folder name" : "Klasör adı",
    "Go back" : "Geri dön",
    "Folder exists already!" : "Klasör zaten mevcut!",
    "New Folder" : "Yeni Klasör",
    "Create" : "Oluştur",
    "Explore" : "Keşfet",
    "Deleted feed" : "Beslemeyi sil",
    "Undo delete feed" : "Beslemeyi geri al",
    "Rename" : "Yeniden adlandır",
    "Menu" : "Menü",
    "No feed ordering" : "Besleme sıralaması yok",
    "Reversed feed ordering" : "Ters besleme sıralaması",
    "Normal feed ordering" : "Normal besleme sıralaması",
    "Enable full text feed fetching" : "Tam metin besleme getirmesini etkinleştir",
    "Disable full text feed fetching" : "Tam metin besleme getirmesini kapat",
    "Rename feed" : "Beslemeyi yeniden adlandır",
    "Delete feed" : "Beslemeyi sil",
    "Mark all articles read" : "Tüm makaleleri okundu işaretle",
    "Dismiss" : "İptal et",
    "Collapse" : "Daralt",
    "Deleted folder" : "Klasör silindi",
    "Undo delete folder" : "Klasör silmeyi geri al",
    "Rename folder" : "Klasörü yeniden adlandır",
    "Delete folder" : "Klasörü sil",
    "Starred" : "Yıldızlı",
    "Unread articles" : "Okunmamış makaleler",
    "All articles" : "Tüm makaleler",
    "Settings" : "Ayarlar",
    "Keyboard shortcuts" : "Klavye kısayolları",
    "Disable mark read through scrolling" : "Kaydırma sırasında okundu olarak işaretlemeyi kapat",
    "Compact view" : "Sıkışık görünüm",
    "Expand articles on key navigation" : "Tuşla gezinme sırasında makaleleri genişlet",
    "Show all articles" : "Tüm makaleleri göster",
    "Reverse ordering (oldest on top)" : "Sıralamayı tersine çevir (en eski üstte)",
    "Subscriptions (OPML)" : "Abonelikler (OPML)",
    "Import" : "İçe aktar",
    "Export" : "Dışa aktar",
    "Error when importing: file does not contain valid OPML" : "Dosya alımında hata: dosya geçerli OPML içermiyor",
    "Unread/Starred Articles" : "Okunmamış/Yıldızlı Makaleler",
    "Error when importing: file does not contain valid JSON" : "İçe alınırken hata: dosya geçerli JSON içermiyor"
},
"nplurals=2; plural=(n > 1);");
